import { Application, AndroidApplication } from '@nativescript/core';
import { deserialize, firebase, FirebaseApp, FirebaseError } from '@nativescript/firebase-core';
import { ShortLinkType } from './common';
let defaultDynamicLinks;
const fb = firebase();
Object.defineProperty(fb, 'dynamicLinks', {
    value: () => {
        if (!defaultDynamicLinks) {
            defaultDynamicLinks = new DynamicLinks();
        }
        return defaultDynamicLinks;
    },
    writable: false,
});
export class DynamicLinkAnalyticsParameters {
    constructor() {
        this._builder = new com.google.firebase.dynamiclinks.DynamicLink.GoogleAnalyticsParameters.Builder();
    }
    static fromNative(link) {
        if (link instanceof com.google.firebase.dynamiclinks.DynamicLink.GoogleAnalyticsParameters) {
            const result = new DynamicLinkAnalyticsParameters();
            result._native = link;
            return result;
        }
        return null;
    }
    get campaign() {
        return this._builder.getCampaign();
    }
    set campaign(value) {
        this._builder.setCampaign(value);
    }
    get content() {
        return this._builder.getContent();
    }
    set content(value) {
        this._builder.setContent(value);
    }
    get medium() {
        return this._builder.getMedium();
    }
    set medium(value) {
        this._builder.setMedium(value);
    }
    get source() {
        return this._builder.getSource();
    }
    set source(value) {
        this._builder.setSource(value);
    }
    get term() {
        return this._builder.getTerm();
    }
    set term(value) {
        this._builder.setTerm(value);
    }
    get native() {
        if (!this._native) {
            return this._builder.build();
        }
        return this._native;
    }
    get android() {
        return this.native;
    }
}
export class DynamicLinkAndroidParameters {
    constructor(packageName) {
        var _a, _b;
        const name = packageName || ((_b = (_a = (Application.android.foregroundActivity || Application.android.startActivity)).getPackageName) === null || _b === void 0 ? void 0 : _b.call(_a));
        this._packageName = name;
        this._builder = new com.google.firebase.dynamiclinks.DynamicLink.AndroidParameters.Builder(name);
    }
    static fromNative(link) {
        if (link instanceof com.google.firebase.dynamiclinks.DynamicLink.AndroidParameters) {
            const result = new DynamicLinkAndroidParameters();
            result._native = link;
            return result;
        }
        return null;
    }
    get fallbackUrl() {
        return this._builder.getFallbackUrl().toString();
    }
    set fallbackUrl(value) {
        try {
            this._builder.setFallbackUrl(android.net.Uri.parse(value));
        }
        catch (error) { }
    }
    get minimumVersion() {
        return this._builder.getMinimumVersion();
    }
    set minimumVersion(value) {
        this._builder.setMinimumVersion(value);
    }
    get packageName() {
        return this._packageName;
    }
    get native() {
        if (!this._native) {
            return this._builder.build();
        }
        return this._native;
    }
    get android() {
        return this.native;
    }
}
export class DynamicLinkIOSParameters {
    constructor(bundleId) {
        this._bundleId = bundleId;
        this._native = new com.google.firebase.dynamiclinks.DynamicLink.IosParameters.Builder(bundleId);
    }
    static fromNative(link) {
        if (link instanceof com.google.firebase.dynamiclinks.DynamicLink.IosParameters) {
            const result = new DynamicLinkIOSParameters();
            result._native = link;
            return result;
        }
        return null;
    }
    get appStoreId() {
        var _a, _b;
        return (_b = (_a = this._builder) === null || _a === void 0 ? void 0 : _a.getAppStoreId) === null || _b === void 0 ? void 0 : _b.call(_a);
    }
    set appStoreId(value) {
        var _a, _b;
        (_b = (_a = this._builder) === null || _a === void 0 ? void 0 : _a.setAppStoreId) === null || _b === void 0 ? void 0 : _b.call(_a, value);
    }
    get bundleId() {
        return this._bundleId;
    }
    get customScheme() {
        var _a, _b;
        return (_b = (_a = this._builder) === null || _a === void 0 ? void 0 : _a.getCustomScheme) === null || _b === void 0 ? void 0 : _b.call(_a);
    }
    set customScheme(value) {
        var _a, _b;
        (_b = (_a = this._builder) === null || _a === void 0 ? void 0 : _a.setCustomScheme) === null || _b === void 0 ? void 0 : _b.call(_a, value);
    }
    get fallbackUrl() {
        return this._fallbackUrl;
    }
    set fallbackUrl(value) {
        var _a, _b;
        try {
            (_b = (_a = this._builder) === null || _a === void 0 ? void 0 : _a.setFallbackUrl) === null || _b === void 0 ? void 0 : _b.call(_a, android.net.Uri.parse(value));
            this._fallbackUrl = value;
        }
        catch (error) { }
    }
    get iPadBundleId() {
        var _a, _b;
        return (_b = (_a = this._builder) === null || _a === void 0 ? void 0 : _a.getIpadBundleId) === null || _b === void 0 ? void 0 : _b.call(_a);
    }
    set iPadBundleId(value) {
        var _a, _b;
        (_b = (_a = this._builder) === null || _a === void 0 ? void 0 : _a.setIpadBundleId) === null || _b === void 0 ? void 0 : _b.call(_a, value);
    }
    get iPadFallbackUrl() {
        var _a, _b, _c, _d;
        return (_d = (_b = (_a = this._builder) === null || _a === void 0 ? void 0 : _a.getIpadFallbackUrl) === null || _b === void 0 ? void 0 : (_c = _b.call(_a)).toString) === null || _d === void 0 ? void 0 : _d.call(_c);
    }
    set iPadFallbackUrl(value) {
        var _a, _b;
        try {
            (_b = (_a = this._builder) === null || _a === void 0 ? void 0 : _a.setIpadFallbackUrl) === null || _b === void 0 ? void 0 : _b.call(_a, android.net.Uri.parse(value));
        }
        catch (error) { }
    }
    get minimumVersion() {
        var _a;
        return (_a = this._builder) === null || _a === void 0 ? void 0 : _a.getMinimumVersion();
    }
    get native() {
        if (!this._native) {
            return this._builder.build();
        }
        return this._native;
    }
    get android() {
        return this.native;
    }
}
export class DynamicLinkITunesParameters {
    constructor() {
        this._builder = new com.google.firebase.dynamiclinks.DynamicLink.ItunesConnectAnalyticsParameters.Builder();
    }
    static fromNative(link) {
        if (link instanceof com.google.firebase.dynamiclinks.DynamicLink.ItunesConnectAnalyticsParameters) {
            const result = new DynamicLinkITunesParameters();
            result._native = link;
            return result;
        }
        return null;
    }
    get affiliateToken() {
        var _a, _b;
        return (_b = (_a = this._builder) === null || _a === void 0 ? void 0 : _a.getAffiliateToken) === null || _b === void 0 ? void 0 : _b.call(_a);
    }
    set affiliateToken(value) {
        var _a, _b;
        (_b = (_a = this._builder) === null || _a === void 0 ? void 0 : _a.setAffiliateToken) === null || _b === void 0 ? void 0 : _b.call(_a, value);
    }
    get campaignToken() {
        var _a, _b;
        return (_b = (_a = this._builder) === null || _a === void 0 ? void 0 : _a.getCampaignToken) === null || _b === void 0 ? void 0 : _b.call(_a);
    }
    set campaignToken(value) {
        var _a, _b;
        (_b = (_a = this._builder) === null || _a === void 0 ? void 0 : _a.setCampaignToken) === null || _b === void 0 ? void 0 : _b.call(_a, value);
    }
    get providerToken() {
        var _a, _b;
        return (_b = (_a = this._builder) === null || _a === void 0 ? void 0 : _a.getProviderToken) === null || _b === void 0 ? void 0 : _b.call(_a);
    }
    set providerToken(value) {
        var _a, _b;
        (_b = (_a = this._builder).setProviderToken) === null || _b === void 0 ? void 0 : _b.call(_a, value);
    }
    get native() {
        if (!this._native) {
            return this._builder.build();
        }
        return this._native;
    }
    get android() {
        return this.native;
    }
}
export class DynamicLinkNavigationParameters {
    constructor() {
        this._builder = new com.google.firebase.dynamiclinks.DynamicLink.NavigationInfoParameters.Builder();
    }
    static fromNative(link) {
        if (link instanceof com.google.firebase.dynamiclinks.DynamicLink.NavigationInfoParameters) {
            const result = new DynamicLinkNavigationParameters();
            result._native = link;
            return result;
        }
        return null;
    }
    get forcedRedirectEnabled() {
        var _a, _b;
        return (_b = (_a = this._builder) === null || _a === void 0 ? void 0 : _a.getForcedRedirectEnabled) === null || _b === void 0 ? void 0 : _b.call(_a);
    }
    set forcedRedirectEnabled(value) {
        var _a, _b;
        (_b = (_a = this._builder) === null || _a === void 0 ? void 0 : _a.setForcedRedirectEnabled) === null || _b === void 0 ? void 0 : _b.call(_a, value);
    }
    get native() {
        if (!this._native) {
            return this._builder.build();
        }
        return this._native;
    }
    get android() {
        return this.native;
    }
}
export class DynamicLinkSocialParameters {
    static fromNative(link) {
        if (link instanceof FIRDynamicLinkSocialMetaTagParameters) {
            const result = new DynamicLinkSocialParameters();
            result._native = link;
            return result;
        }
        return null;
    }
    get descriptionText() {
        var _a, _b;
        return (_b = (_a = this._builder) === null || _a === void 0 ? void 0 : _a.getDescription) === null || _b === void 0 ? void 0 : _b.call(_a);
    }
    set descriptionText(value) {
        var _a, _b;
        (_b = (_a = this._builder) === null || _a === void 0 ? void 0 : _a.getDescription) === null || _b === void 0 ? void 0 : _b.call(_a);
    }
    get imageUrl() {
        var _a, _b, _c, _d;
        return (_d = (_c = (_b = (_a = this._builder) === null || _a === void 0 ? void 0 : _a.getImageUrl) === null || _b === void 0 ? void 0 : _b.call(_a)) === null || _c === void 0 ? void 0 : _c.toString) === null || _d === void 0 ? void 0 : _d.call(_c);
    }
    set imageUrl(value) {
        var _a, _b;
        try {
            (_b = (_a = this._builder) === null || _a === void 0 ? void 0 : _a.setImageUrl) === null || _b === void 0 ? void 0 : _b.call(_a, android.net.Uri.parse(value));
        }
        catch (error) { }
    }
    get title() {
        var _a, _b;
        return (_b = (_a = this._builder) === null || _a === void 0 ? void 0 : _a.getTitle) === null || _b === void 0 ? void 0 : _b.call(_a);
    }
    set title(value) {
        var _a;
        (_a = this._builder) === null || _a === void 0 ? void 0 : _a.setTitle(value);
    }
    get native() {
        if (!this._native) {
            return this._builder.build();
        }
        return this._native;
    }
    get android() {
        return this.native;
    }
}
export class DynamicLinkParameters {
    static fromNative(link, shortLinkType = undefined) {
        if (link instanceof com.google.firebase.dynamiclinks.DynamicLink.Builder) {
            const result = new DynamicLinkParameters();
            result._native = link;
            result._shortLinkType = shortLinkType;
            return result;
        }
        return null;
    }
    get native() {
        return this._native;
    }
    _build() {
        if (this.analytics) {
            this.native.setGoogleAnalyticsParameters(this.analytics.native);
        }
        if (this.android) {
            this.native.setAndroidParameters(this.android.native);
        }
        if (this.ios) {
            this.native.setIosParameters(this.ios.native);
        }
        if (this.itunes) {
            this.native.setItunesConnectAnalyticsParameters(this.itunes.native);
        }
        if (this.navigation) {
            this.native.setNavigationInfoParameters(this.navigation.native);
        }
        if (this.social) {
            this.native.setSocialMetaTagParameters(this.social.native);
        }
        return this.native;
    }
}
export class DynamicLink {
    static fromNative(link) {
        if (link instanceof com.google.firebase.dynamiclinks.PendingDynamicLinkData) {
            const result = new DynamicLink();
            result._native = link;
            return result;
        }
        return null;
    }
    get minimumAppVersion() {
        return String(this.native.getMinimumAppVersion());
    }
    get url() {
        var _a, _b, _c, _d;
        return (_d = (_c = (_b = (_a = this.native) === null || _a === void 0 ? void 0 : _a.getLink) === null || _b === void 0 ? void 0 : _b.call(_a)) === null || _c === void 0 ? void 0 : _c.toString) === null || _d === void 0 ? void 0 : _d.call(_c);
    }
    get utmParameters() {
        return deserialize(this.native.getUtmParameters());
    }
    get native() {
        return this._native;
    }
    get android() {
        return this.native;
    }
    toJSON() {
        return {
            minimumAppVersion: this.minimumAppVersion,
            url: this.url,
            utmParameters: this.utmParameters,
        };
    }
}
export class DynamicLinks {
    constructor() {
        if (defaultDynamicLinks) {
            return defaultDynamicLinks;
        }
        defaultDynamicLinks = this;
        if (!DynamicLinks._didInit) {
            DynamicLinks._callback = new org.nativescript.firebase.dynamic_links.FirebaseDynamicLinks.Callback({
                onSuccess(param0) {
                    if (typeof DynamicLinks._onLink === 'function') {
                        DynamicLinks._onLink(DynamicLink.fromNative(param0));
                    }
                },
                onError(param0) {
                    console.error('Unknown error occurred when attempting to handle a universal link', param0);
                },
            });
            Application.android.on(AndroidApplication.activityNewIntentEvent, (data) => {
                org.nativescript.firebase.dynamic_links.FirebaseDynamicLinks.onNewIntent(com.google.firebase.dynamiclinks.FirebaseDynamicLinks.getInstance(), data.intent, DynamicLinks._callback);
            });
            DynamicLinks._didInit = true;
        }
    }
    buildLink(link) {
        return new Promise((resolve, reject) => {
            if (link._shortLinkType) {
                org.nativescript.firebase.dynamic_links.FirebaseDynamicLinks.buildShortLink(link._build(), new org.nativescript.firebase.dynamic_links.FirebaseDynamicLinks.Callback({
                    onSuccess(param0) {
                        resolve(param0.getShortLink().toString());
                    },
                    onError(param0) {
                        reject(FirebaseError.fromNative(param0));
                    },
                }));
            }
            else {
                resolve(link.native.buildDynamicLink().getUri().toString());
            }
        });
    }
    createLink(link, domainUriPrefix) {
        const dl = this.native.createDynamicLink();
        try {
            dl.setLink(android.net.Uri.parse(link));
        }
        catch (error) { }
        dl.setDomainUriPrefix(domainUriPrefix);
        return DynamicLinkParameters.fromNative(dl);
    }
    createShortLink(link, domainUriPrefix, shortLinkType = ShortLinkType.DEFAULT) {
        const dl = this.native.createDynamicLink();
        try {
            dl.setLink(android.net.Uri.parse(link));
        }
        catch (error) { }
        dl.setDomainUriPrefix(domainUriPrefix);
        return DynamicLinkParameters.fromNative(dl, shortLinkType);
    }
    onLink(listener) {
        DynamicLinks._onLink = listener;
    }
    resolveLink(link) {
        return new Promise((resolve, reject) => {
            org.nativescript.firebase.dynamic_links.FirebaseDynamicLinks.resolveLink(this.native, link, new org.nativescript.firebase.dynamic_links.FirebaseDynamicLinks.Callback({
                onSuccess(param0) {
                    resolve(DynamicLink.fromNative(param0));
                },
                onError(param0) {
                    reject(FirebaseError.fromNative(param0));
                },
            }));
        });
    }
    get native() {
        if (!this._native) {
            this._native = com.google.firebase.dynamiclinks.FirebaseDynamicLinks.getInstance();
        }
        return this._native;
    }
    get android() {
        return this.native;
    }
    get app() {
        if (!this._app) {
            // @ts-ignore
            this._app = FirebaseApp.fromNative(com.google.firebase.FirebaseApp.getInstance());
        }
        return this._app;
    }
}
DynamicLinks._didInit = false;
//# sourceMappingURL=index.android.js.map